# neoscore.western

This module contains relatively high level classes for drawing
explicitly spaced western classical notation. It supports staves,
clefs, key/time signatures, chords, rests, and more.

Its most notable limitation is that it does not support automatic
horizontal layout of elements, and so is not a suitable substitute for
fully-featured scorewriters. It does have fairly good support for
vertical layout, for instance automatic vertical positioning of chord
noteheads, accidentals, and ledger lines.
